##  Username and Password
Enter the credentials for the SAP Signavio user account for authenticating the integration. We recommend having a dedicated user account with an ‘API Edition’ license for the integration.
Ensure that this user account has the necessary permissions, such as the ability to read processes or create dictionary items. To learn more, see [Minimum Access Rights for Integration](https://help.sap.com/docs/leanix/ea/configuring-integration?locale=en-US&state=PRODUCTION&version=CLOUD#loio275c64207a441014b145d1ff0fd5f0f5__minimum_access_rights_for_integration).
